@@ -7,7 +7,7 @@ PID=$!
 
 # Stop redis-server
 cleanup(){
-    kill -9 $PID
+    kill -9 $PID || true
 }
 
 trap cleanup INT EXIT TERM ALRM
